Field

Struct Field 

pub struct Field<T> { /* private fields */ }
A single deserializable field in a struct or enum variant. The field has a static name, which corresponds to the name of the field in the YAML. Generally this matches the internal field name, but not always. Fields are required by default, but can be made optional with opt or or.

Implementations

Source

impl<T> Field<T>

pub fn new(name: &'static str) -> Self

pub fn opt(self) -> Self
where T: Default,

Pre-populate this field with T’s default value. If the field is not deserialized, the default value will be used instead.

pub fn or(self, value: T) -> Self

Pre-populate this field with the given default value. If the field is not deserialized, the default value will be used instead.