LocatedError

Struct LocatedError 

pub struct LocatedError<E> {
    pub error: E,
    pub location: SourceIdLocation,
}
An error paired with the source location in YAML where the error occurred

This doesn’t implement Error because this isn’t immediately displayable. The location needs to be resolved to make this presentable.

Fields

error: E

Error that occurred

location: SourceIdLocation

Source location of the error. This is an unresolved location, meaning it contains a source ID instead of a source path.

Implementations

Source

impl<E> LocatedError<E>

pub fn into_error(self) -> E

Move the inner error out

Source

impl LocatedError<YamlErrorKind>

pub fn other( error: impl Into<Box<dyn StdError + Send + Sync>>, location: SourceIdLocation, ) -> Self

Create a new Other from any error type

pub fn unexpected(expected: Expected, actual: SourcedYaml<'_>) -> Self

Create a new Unexpected from the expected type and actual value