pub struct LocatedError<E> {
pub error: E,
pub location: SourceIdLocation,
}Expand description
An error paired with the source location in YAML where the error occurred
This doesn’t implement Error because this isn’t immediately displayable.
The location needs to be resolved to make this presentable.
Fields
error: EError that occurred
location: SourceIdLocationSource location of the error. This is an unresolved location, meaning it contains a source ID instead of a source path.
Implementations
Sourceimpl<E> LocatedError<E>
impl<E> LocatedError<E>
Sourcepub fn into_error(self) -> E
pub fn into_error(self) -> E
Move the inner error out
Sourceimpl LocatedError<YamlErrorKind>
impl LocatedError<YamlErrorKind>
Sourcepub fn other(
error: impl Into<Box<dyn StdError + Send + Sync>>,
location: SourceIdLocation,
) -> Self
pub fn other( error: impl Into<Box<dyn StdError + Send + Sync>>, location: SourceIdLocation, ) -> Self
Create a new Other from any error type
Sourcepub fn unexpected(expected: Expected, actual: SourcedYaml<'_>) -> Self
pub fn unexpected(expected: Expected, actual: SourcedYaml<'_>) -> Self
Create a new Unexpected from the expected type and actual value